@@ -145,7 +145,7 @@ lasso_reg_old<-function(M,Y,K,eps,priors){
 
 
 lasso_reg2<-function(M,Y,eps,foldid=foldid,priors){
-  #require(glmnet)
+  requireNamespace("glmnet")
   if(is.null(priors)) priors<-rep(1,nrow(M))
   cvglmnet<-try(glmnet::cv.glmnet(t(M),Y,foldid=foldid,penalty.factor=priors,intercept=FALSE))
 #  n<-try(which(cvglmnet$cvm==min(cvglmnet$cvm)))
@@ -154,7 +154,7 @@ lasso_reg2<-function(M,Y,eps,foldid=foldid,priors){
 #  model<-try(glmnet(t(M),Y,intercept=FALSE,thresh=10^(-5),penalty.factor=priors,lambda=lambda))
 #  coef(cv.fit,s="lambda.min")
 #  repu<-try(as.vector(coef(model)[-1]))
-  repu<-try(as.vector(glmnet::coef.cv.glmnet(cvglmnet,s="lambda.min")[-1]))
+  repu<-try(as.vector(coef(cvglmnet,s="lambda.min")[-1]))
   if(!is.vector(repu)){repu<-rep(0,dim(M)[1])}
   return(repu)
 }
